@@ -34,11 +34,11 @@
 VIR_LOG_INIT("bhyve.bhyve_domain");
 
 static void *
-bhyveDomainObjPrivateAlloc(void *opaque G_GNUC_UNUSED)
+bhyveDomainObjPrivateAlloc(void *opaque)
 {
-    bhyveDomainObjPrivate *priv;
+    bhyveDomainObjPrivate *priv = g_new0(bhyveDomainObjPrivate, 1);
 
-    priv = g_new0(bhyveDomainObjPrivate, 1);
+    priv->driver = opaque;
 
     return priv;
 }
