@@ -32,21 +32,6 @@
 
 VIR_LOG_INIT("ch.ch_domain");
 
-static void
-virCHDomainObjResetJob(virCHDomainObjPrivate *priv)
-{
-    virDomainJobObj *job = &priv->job;
-
-    job->active = VIR_JOB_NONE;
-    job->owner = 0;
-}
-
-static void
-virCHDomainObjFreeJob(virCHDomainObjPrivate *priv)
-{
-    ignore_value(virCondDestroy(&priv->job.cond));
-}
-
 /*
  * obj must be locked before calling, virCHDriver must NOT be locked
  *
@@ -88,7 +73,7 @@ virCHDomainObjBeginJob(virDomainObj *obj, virDomainJob job)
         }
     }
 
-    virCHDomainObjResetJob(priv);
+    virDomainObjResetJob(&priv->job);
 
     VIR_DEBUG("Starting job: %s", virDomainJobTypeToString(job));
     priv->job.active = job;
@@ -112,7 +97,7 @@ virCHDomainObjEndJob(virDomainObj *obj)
     VIR_DEBUG("Stopping job: %s",
               virDomainJobTypeToString(job));
 
-    virCHDomainObjResetJob(priv);
+    virDomainObjResetJob(&priv->job);
     virCondSignal(&priv->job.cond);
 }
 
@@ -132,13 +117,13 @@ virCHDomainObjPrivateAlloc(void *opaque)
 
     priv = g_new0(virCHDomainObjPrivate, 1);
 
-    if (virDomainObjInitJob(&priv->job, NULL) < 0) {
+    if (virDomainObjInitJob(&priv->job, NULL, NULL) < 0) {
         g_free(priv);
         return NULL;
     }
 
     if (!(priv->chrdevs = virChrdevAlloc())) {
-        virCHDomainObjFreeJob(priv);
+        virDomainObjClearJob(&priv->job);
         g_free(priv);
         return NULL;
     }
@@ -153,7 +138,7 @@ virCHDomainObjPrivateFree(void *data)
     virCHDomainObjPrivate *priv = data;
 
     virChrdevFree(priv->chrdevs);
-    virCHDomainObjFreeJob(priv);
+    virDomainObjClearJob(&priv->job);
     g_free(priv->machineName);
     g_free(priv);
 }
