@@ -212,7 +212,7 @@ virCPUGetHost(virArch arch,
               virDomainCapsCPUModels *models);
 
 virCPUDef *
-virCPUProbeHost(virArch arch) G_GNUC_NO_INLINE;
+virCPUProbeHost(virArch arch) G_NO_INLINE;
 
 virCPUDef *
 virCPUBaseline(virArch arch,
