@@ -155,6 +155,7 @@ struct _virDomainJobObj {
     virCond cond;               /* Use to coordinate jobs */
 
     int jobsQueued;
+    unsigned int maxQueuedJobs;
 
     /* The following members are for VIR_JOB_* */
     virDomainJob active;        /* currently running job */
@@ -184,6 +185,8 @@ struct _virDomainJobObj {
 
     void *privateData;                  /* job specific collection of data */
     virDomainObjPrivateJobCallbacks *cb;
+    virDomainJobDataPrivateDataCallbacks *jobDataPrivateCb; /* callbacks for privateData of
+                                                               virDomainJobData, can be NULL */
 };
 
 
@@ -196,6 +199,7 @@ typedef int (*virDomainObjPrivateJobFormat)(virBuffer *,
 typedef int (*virDomainObjPrivateJobParse)(xmlXPathContextPtr,
                                            virDomainJobObj *,
                                            virDomainObj *);
+typedef void (*virDomainObjPrivateSaveStatus)(virDomainObj *obj);
 
 struct _virDomainObjPrivateJobCallbacks {
    virDomainObjPrivateJobAlloc allocJobPrivate;
@@ -203,8 +207,30 @@ struct _virDomainObjPrivateJobCallbacks {
    virDomainObjPrivateJobReset resetJobPrivate;
    virDomainObjPrivateJobFormat formatJobPrivate;
    virDomainObjPrivateJobParse parseJobPrivate;
+   virDomainObjPrivateSaveStatus saveStatusPrivate;
 };
 
 
 int virDomainObjInitJob(virDomainJobObj *job,
-                        virDomainObjPrivateJobCallbacks *cb);
+                        virDomainObjPrivateJobCallbacks *cb,
+                        virDomainJobDataPrivateDataCallbacks *jobDataPrivateCb);
+
+void virDomainObjResetJob(virDomainJobObj *job);
+
+void virDomainObjResetAgentJob(virDomainJobObj *job);
+
+void virDomainObjResetAsyncJob(virDomainJobObj *job);
+
+int virDomainObjPreserveJob(virDomainJobObj *currJob,
+                            virDomainJobObj *job);
+
+void virDomainObjClearJob(virDomainJobObj *job);
+G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC(virDomainJobObj, virDomainObjClearJob);
+
+bool virDomainTrackJob(virDomainJob job);
+
+bool virDomainNestedJobAllowed(virDomainJobObj *jobs, virDomainJob newJob);
+
+bool virDomainObjCanSetJob(virDomainJobObj *job,
+                           virDomainJob newJob,
+                           virDomainAgentJob newAgentJob);
