@@ -44,22 +44,6 @@
 VIR_LOG_INIT("libxl.libxl_domain");
 
 
-static void
-libxlDomainObjResetJob(libxlDomainObjPrivate *priv)
-{
-    virDomainJobObj *job = &priv->job;
-
-    job->active = VIR_JOB_NONE;
-    job->owner = 0;
-}
-
-static void
-libxlDomainObjFreeJob(libxlDomainObjPrivate *priv)
-{
-    ignore_value(virCondDestroy(&priv->job.cond));
-    virDomainJobDataFree(priv->job.current);
-}
-
 /* Give up waiting for mutex after 30 seconds */
 #define LIBXL_JOB_WAIT_TIME (1000ull * 30)
 
@@ -92,7 +76,7 @@ libxlDomainObjBeginJob(libxlDriverPrivate *driver G_GNUC_UNUSED,
             goto error;
     }
 
-    libxlDomainObjResetJob(priv);
+    virDomainObjResetJob(&priv->job);
 
     VIR_DEBUG("Starting job: %s", virDomainJobTypeToString(job));
     priv->job.active = job;
@@ -140,7 +124,7 @@ libxlDomainObjEndJob(libxlDriverPrivate *driver G_GNUC_UNUSED,
     VIR_DEBUG("Stopping job: %s",
               virDomainJobTypeToString(job));
 
-    libxlDomainObjResetJob(priv);
+    virDomainObjResetJob(&priv->job);
     virCondSignal(&priv->job.cond);
 }
 
@@ -177,7 +161,7 @@ libxlDomainObjPrivateAlloc(void *opaque G_GNUC_UNUSED)
         return NULL;
     }
 
-    if (virDomainObjInitJob(&priv->job, NULL) < 0) {
+    if (virDomainObjInitJob(&priv->job, NULL, NULL) < 0) {
         virChrdevFree(priv->devs);
         g_free(priv);
         return NULL;
@@ -194,7 +178,7 @@ libxlDomainObjPrivateFree(void *data)
     libxlDomainObjPrivate *priv = data;
 
     g_free(priv->lockState);
-    libxlDomainObjFreeJob(priv);
+    virDomainObjClearJob(&priv->job);
     virChrdevFree(priv->devs);
     g_free(priv);
 }
