@@ -23,9 +23,7 @@
 #include "qemu_conf.h"
 #include "qemu_capabilities.h"
 #include "qemu_monitor.h"
-#include "qemu_process.h"
 #include "qemu_backup.h"
-#include "qemu_monitor_json.h"
 #include "qemu_checkpoint.h"
 #include "qemu_command.h"
 #include "qemu_security.h"
@@ -35,9 +33,6 @@
 #include "virerror.h"
 #include "virlog.h"
 #include "virbuffer.h"
-#include "viralloc.h"
-#include "virxml.h"
-#include "virstring.h"
 #include "backup_conf.h"
 #include "virdomaincheckpointobjlist.h"
 
@@ -130,9 +125,9 @@ qemuBackupDiskDataCleanupOne(virDomainObj *vm,
 
     if (!dd->started) {
         if (dd->added) {
-            qemuDomainObjEnterMonitor(priv->driver, vm);
+            qemuDomainObjEnterMonitor(vm);
             qemuBlockStorageSourceAttachRollback(priv->mon, dd->crdata->srcdata[0]);
-            qemuDomainObjExitMonitor(priv->driver, vm);
+            qemuDomainObjExitMonitor(vm);
         }
 
         if (dd->created) {
@@ -265,7 +260,7 @@ qemuBackupDiskPrepareDataOne(virDomainObj *vm,
         return -1;
     }
 
-    if (!qemuDomainDiskBlockJobIsSupported(vm, dd->domdisk))
+    if (!qemuDomainDiskBlockJobIsSupported(dd->domdisk))
         return -1;
 
     if (dd->store->format == VIR_STORAGE_FILE_NONE) {
@@ -466,15 +461,15 @@ qemuBackupDiskPrepareOneStorage(virDomainObj *vm,
 
         if (qemuBlockStorageSourceCreate(vm, dd->store, dd->backingStore, NULL,
                                          dd->crdata->srcdata[0],
-                                         QEMU_ASYNC_JOB_BACKUP) < 0)
+                                         VIR_ASYNC_JOB_BACKUP) < 0)
             return -1;
     } else {
-        if (qemuDomainObjEnterMonitorAsync(priv->driver, vm, QEMU_ASYNC_JOB_BACKUP) < 0)
+        if (qemuDomainObjEnterMonitorAsync(vm, VIR_ASYNC_JOB_BACKUP) < 0)
             return -1;
 
         rc = qemuBlockStorageSourceAttachApply(priv->mon, dd->crdata->srcdata[0]);
 
-        qemuDomainObjExitMonitor(priv->driver, vm);
+        qemuDomainObjExitMonitor(vm);
         if (rc < 0)
             return -1;
     }
@@ -541,7 +536,7 @@ qemuBackupBeginPullExportDisks(virDomainObj *vm,
         if (!dd->backupdisk->exportname)
             dd->backupdisk->exportname = g_strdup(dd->domdisk->dst);
 
-        if (qemuBlockExportAddNBD(vm, NULL,
+        if (qemuBlockExportAddNBD(vm,
                                   dd->store,
                                   dd->backupdisk->exportname,
                                   false,
@@ -622,8 +617,8 @@ qemuBackupJobTerminate(virDomainObj *vm,
 
     g_clear_pointer(&priv->backup, virDomainBackupDefFree);
 
-    if (priv->job.asyncJob == QEMU_ASYNC_JOB_BACKUP)
-        qemuDomainObjEndAsyncJob(priv->driver, vm);
+    if (priv->job.asyncJob == VIR_ASYNC_JOB_BACKUP)
+        qemuDomainObjEndAsyncJob(vm);
 }
 
 
@@ -676,12 +671,12 @@ qemuBackupJobCancelBlockjobs(virDomainObj *vm,
         if (backupdisk->state != VIR_DOMAIN_BACKUP_DISK_STATE_RUNNING)
             continue;
 
-        if (qemuDomainObjEnterMonitorAsync(priv->driver, vm, asyncJob) < 0)
+        if (qemuDomainObjEnterMonitorAsync(vm, asyncJob) < 0)
             return;
 
         rc = qemuMonitorBlockJobCancel(priv->mon, job->name, true);
 
-        qemuDomainObjExitMonitor(priv->driver, vm);
+        qemuDomainObjExitMonitor(vm);
 
         if (rc == 0) {
             backupdisk->state = VIR_DOMAIN_BACKUP_DISK_STATE_CANCELLING;
@@ -791,13 +786,13 @@ qemuBackupBegin(virDomainObj *vm,
      * infrastructure for async jobs. We'll allow standard modify-type jobs
      * as the interlocking of conflicting operations is handled on the block
      * job level */
-    if (qemuDomainObjBeginAsyncJob(priv->driver, vm, QEMU_ASYNC_JOB_BACKUP,
+    if (qemuDomainObjBeginAsyncJob(vm, VIR_ASYNC_JOB_BACKUP,
                                    VIR_DOMAIN_JOB_OPERATION_BACKUP, flags) < 0)
         return -1;
 
-    qemuDomainObjSetAsyncJobMask(vm, (QEMU_JOB_DEFAULT_MASK |
-                                      JOB_MASK(QEMU_JOB_SUSPEND) |
-                                      JOB_MASK(QEMU_JOB_MODIFY)));
+    qemuDomainObjSetAsyncJobMask(vm, (VIR_JOB_DEFAULT_MASK |
+                                      JOB_MASK(VIR_JOB_SUSPEND) |
+                                      JOB_MASK(VIR_JOB_MODIFY)));
     qemuDomainJobSetStatsType(priv->job.current,
                               QEMU_DOMAIN_JOB_STATS_TYPE_BACKUP);
 
@@ -807,12 +802,6 @@ qemuBackupBegin(virDomainObj *vm,
         goto endjob;
     }
 
-    if (!virQEMUCapsGet(priv->qemuCaps, QEMU_CAPS_BLOCKDEV_BACKUP)) {
-        virReportError(VIR_ERR_OPERATION_UNSUPPORTED, "%s",
-                       _("backup is not supported with this QEMU"));
-        goto endjob;
-    }
-
     if (virDomainBackupAlignDisks(def, vm->def, suffix) < 0)
         goto endjob;
 
@@ -856,7 +845,7 @@ qemuBackupBegin(virDomainObj *vm,
             goto endjob;
     }
 
-    if (!(blockNamedNodeData = qemuBlockGetNamedNodeData(vm, QEMU_ASYNC_JOB_BACKUP)))
+    if (!(blockNamedNodeData = qemuBlockGetNamedNodeData(vm, VIR_ASYNC_JOB_BACKUP)))
         goto endjob;
 
     if ((ndd = qemuBackupDiskPrepareData(vm, def, blockNamedNodeData, actions,
@@ -874,7 +863,7 @@ qemuBackupBegin(virDomainObj *vm,
 
     priv->backup = g_steal_pointer(&def);
 
-    if (qemuDomainObjEnterMonitorAsync(priv->driver, vm, QEMU_ASYNC_JOB_BACKUP) < 0)
+    if (qemuDomainObjEnterMonitorAsync(vm, VIR_ASYNC_JOB_BACKUP) < 0)
         goto endjob;
 
     if (pull) {
@@ -893,7 +882,7 @@ qemuBackupBegin(virDomainObj *vm,
     if (rc == 0)
         rc = qemuMonitorTransaction(priv->mon, &actions);
 
-    qemuDomainObjExitMonitor(priv->driver, vm);
+    qemuDomainObjExitMonitor(vm);
     if (rc < 0)
         goto endjob;
 
@@ -910,15 +899,15 @@ qemuBackupBegin(virDomainObj *vm,
     }
 
     if (pull) {
-        if (qemuDomainObjEnterMonitorAsync(priv->driver, vm, QEMU_ASYNC_JOB_BACKUP) < 0)
+        if (qemuDomainObjEnterMonitorAsync(vm, VIR_ASYNC_JOB_BACKUP) < 0)
             goto endjob;
         /* note that if the export fails we've already created the checkpoint
          * and we will not delete it */
         rc = qemuBackupBeginPullExportDisks(vm, dd, ndd);
-        qemuDomainObjExitMonitor(priv->driver, vm);
+        qemuDomainObjExitMonitor(vm);
 
         if (rc < 0) {
-            qemuBackupJobCancelBlockjobs(vm, priv->backup, false, QEMU_ASYNC_JOB_BACKUP);
+            qemuBackupJobCancelBlockjobs(vm, priv->backup, false, VIR_ASYNC_JOB_BACKUP);
             goto endjob;
         }
     }
@@ -932,14 +921,14 @@ qemuBackupBegin(virDomainObj *vm,
     qemuCheckpointRollbackMetadata(vm, chk);
 
     if (!job_started && (nbd_running || tlsAlias || tlsSecretAlias) &&
-        qemuDomainObjEnterMonitorAsync(priv->driver, vm, QEMU_ASYNC_JOB_BACKUP) == 0) {
+        qemuDomainObjEnterMonitorAsync(vm, VIR_ASYNC_JOB_BACKUP) == 0) {
         if (nbd_running)
             ignore_value(qemuMonitorNBDServerStop(priv->mon));
         if (tlsAlias)
             ignore_value(qemuMonitorDelObject(priv->mon, tlsAlias, false));
         if (tlsSecretAlias)
             ignore_value(qemuMonitorDelObject(priv->mon, tlsSecretAlias, false));
-        qemuDomainObjExitMonitor(priv->driver, vm);
+        qemuDomainObjExitMonitor(vm);
     }
 
     if (ret < 0 && !job_started && priv->backup)
@@ -948,7 +937,7 @@ qemuBackupBegin(virDomainObj *vm,
     if (ret == 0)
         qemuDomainObjReleaseAsyncJob(vm);
     else
-        qemuDomainObjEndAsyncJob(priv->driver, vm);
+        qemuDomainObjEndAsyncJob(vm);
 
     return ret;
 }
@@ -1000,14 +989,14 @@ qemuBackupNotifyBlockjobEnd(virDomainObj *vm,
         return;
 
     if (backup->type == VIR_DOMAIN_BACKUP_TYPE_PULL) {
-        if (qemuDomainObjEnterMonitorAsync(priv->driver, vm, asyncJob) < 0)
+        if (qemuDomainObjEnterMonitorAsync(vm, asyncJob) < 0)
             return;
         ignore_value(qemuMonitorNBDServerStop(priv->mon));
         if (backup->tlsAlias)
             ignore_value(qemuMonitorDelObject(priv->mon, backup->tlsAlias, false));
         if (backup->tlsSecretAlias)
             ignore_value(qemuMonitorDelObject(priv->mon, backup->tlsSecretAlias, false));
-        qemuDomainObjExitMonitor(priv->driver, vm);
+        qemuDomainObjExitMonitor(vm);
 
         /* update the final statistics with the current job's data */
         backup->pull_tmp_used += cur;
@@ -1137,8 +1126,7 @@ qemuBackupGetJobInfoStatsUpdateOne(virDomainObj *vm,
 
 
 int
-qemuBackupGetJobInfoStats(virQEMUDriver *driver,
-                          virDomainObj *vm,
+qemuBackupGetJobInfoStats(virDomainObj *vm,
                           virDomainJobData *jobData)
 {
     qemuDomainJobDataPrivate *privJob = jobData->privateData;
@@ -1161,11 +1149,11 @@ qemuBackupGetJobInfoStats(virQEMUDriver *driver,
 
     jobData->status = VIR_DOMAIN_JOB_STATUS_ACTIVE;
 
-    qemuDomainObjEnterMonitor(driver, vm);
+    qemuDomainObjEnterMonitor(vm);
 
     rc = qemuMonitorGetJobInfo(priv->mon, &blockjobs, &nblockjobs);
 
-    qemuDomainObjExitMonitor(driver, vm);
+    qemuDomainObjExitMonitor(vm);
     if (rc < 0)
         goto cleanup;
 
