@@ -150,81 +150,6 @@ qemuDomainEventEmitJobCompleted(virQEMUDriver *driver,
 }
 
 
-static void
-qemuDomainObjResetJob(virDomainJobObj *job)
-{
-    job->active = VIR_JOB_NONE;
-    job->owner = 0;
-    g_clear_pointer(&job->ownerAPI, g_free);
-    job->started = 0;
-}
-
-
-static void
-qemuDomainObjResetAgentJob(virDomainJobObj *job)
-{
-    job->agentActive = VIR_AGENT_JOB_NONE;
-    job->agentOwner = 0;
-    g_clear_pointer(&job->agentOwnerAPI, g_free);
-    job->agentStarted = 0;
-}
-
-
-static void
-qemuDomainObjResetAsyncJob(virDomainJobObj *job)
-{
-    job->asyncJob = VIR_ASYNC_JOB_NONE;
-    job->asyncOwner = 0;
-    g_clear_pointer(&job->asyncOwnerAPI, g_free);
-    job->asyncStarted = 0;
-    job->phase = 0;
-    job->mask = VIR_JOB_DEFAULT_MASK;
-    job->abortJob = false;
-    VIR_FREE(job->error);
-    g_clear_pointer(&job->current, virDomainJobDataFree);
-    job->apiFlags = 0;
-
-    if (job->cb)
-        job->cb->resetJobPrivate(job->privateData);
-}
-
-
-/**
- * qemuDomainObjPreserveJob
- * @param obj domain with a job that needs to be preserved
- * @param job structure where to store job details from @obj
- *
- * Saves the current job details from @obj to @job and resets the job in @obj.
- *
- * Returns 0 on success, -1 on failure.
- */
-int
-qemuDomainObjPreserveJob(virDomainObj *obj,
-                         virDomainJobObj *job)
-{
-    qemuDomainObjPrivate *priv = obj->privateData;
-
-    memset(job, 0, sizeof(*job));
-    job->active = priv->job.active;
-    job->owner = priv->job.owner;
-    job->asyncJob = priv->job.asyncJob;
-    job->asyncOwner = priv->job.asyncOwner;
-    job->asyncStarted = priv->job.asyncStarted;
-    job->phase = priv->job.phase;
-    job->privateData = g_steal_pointer(&priv->job.privateData);
-    job->apiFlags = priv->job.apiFlags;
-
-    if (priv->job.cb &&
-        !(priv->job.privateData = priv->job.cb->allocJobPrivate()))
-        return -1;
-    job->cb = priv->job.cb;
-
-    qemuDomainObjResetJob(&priv->job);
-    qemuDomainObjResetAsyncJob(&priv->job);
-    return 0;
-}
-
-
 void
 qemuDomainObjRestoreAsyncJob(virDomainObj *vm,
                              virDomainAsyncJob asyncJob,
@@ -260,27 +185,6 @@ qemuDomainObjRestoreAsyncJob(virDomainObj *vm,
 }
 
 
-void
-qemuDomainObjClearJob(virDomainJobObj *job)
-{
-    qemuDomainObjResetJob(job);
-    qemuDomainObjResetAsyncJob(job);
-    g_clear_pointer(&job->current, virDomainJobDataFree);
-    g_clear_pointer(&job->completed, virDomainJobDataFree);
-    virCondDestroy(&job->cond);
-    virCondDestroy(&job->asyncCond);
-
-    if (job->cb)
-        g_clear_pointer(&job->privateData, job->cb->freeJobPrivate);
-}
-
-bool
-qemuDomainTrackJob(virDomainJob job)
-{
-    return (VIR_DOMAIN_TRACK_JOBS & JOB_MASK(job)) != 0;
-}
-
-
 int
 qemuDomainJobDataUpdateTime(virDomainJobData *jobData)
 {
@@ -772,8 +676,8 @@ qemuDomainObjDiscardAsyncJob(virDomainObj *obj)
     qemuDomainObjPrivate *priv = obj->privateData;
 
     if (priv->job.active == VIR_JOB_ASYNC_NESTED)
-        qemuDomainObjResetJob(&priv->job);
-    qemuDomainObjResetAsyncJob(&priv->job);
+        virDomainObjResetJob(&priv->job);
+    virDomainObjResetAsyncJob(&priv->job);
     qemuDomainSaveStatus(obj);
 }
 
@@ -793,31 +697,11 @@ qemuDomainObjReleaseAsyncJob(virDomainObj *obj)
     priv->job.asyncOwner = 0;
 }
 
-static bool
-qemuDomainNestedJobAllowed(virDomainJobObj *jobs, virDomainJob newJob)
-{
-    return !jobs->asyncJob ||
-           newJob == VIR_JOB_NONE ||
-           (jobs->mask & JOB_MASK(newJob)) != 0;
-}
-
-static bool
-qemuDomainObjCanSetJob(virDomainJobObj *job,
-                       virDomainJob newJob,
-                       virDomainAgentJob newAgentJob)
-{
-    return ((newJob == VIR_JOB_NONE ||
-             job->active == VIR_JOB_NONE) &&
-            (newAgentJob == VIR_AGENT_JOB_NONE ||
-             job->agentActive == VIR_AGENT_JOB_NONE));
-}
-
 /* Give up waiting for mutex after 30 seconds */
 #define QEMU_JOB_WAIT_TIME (1000ull * 30)
 
 /**
  * qemuDomainObjBeginJobInternal:
- * @driver: qemu driver
  * @obj: domain object
  * @job: virDomainJob to start
  * @asyncJob: virDomainAsyncJob to start
@@ -838,8 +722,7 @@ qemuDomainObjCanSetJob(virDomainJobObj *job,
  *         -1 otherwise.
  */
 static int ATTRIBUTE_NONNULL(1)
-qemuDomainObjBeginJobInternal(virQEMUDriver *driver,
-                              virDomainObj *obj,
+qemuDomainObjBeginJobInternal(virDomainObj *obj,
                               virDomainJob job,
                               virDomainAgentJob agentJob,
                               virDomainAsyncJob asyncJob,
@@ -849,7 +732,6 @@ qemuDomainObjBeginJobInternal(virQEMUDriver *driver,
     unsigned long long now;
     unsigned long long then;
     bool nested = job == VIR_JOB_ASYNC_NESTED;
-    g_autoptr(virQEMUDriverConfig) cfg = virQEMUDriverGetConfig(driver);
     const char *blocker = NULL;
     const char *agentBlocker = NULL;
     int ret = -1;
@@ -878,12 +760,12 @@ qemuDomainObjBeginJobInternal(virQEMUDriver *driver,
  retry:
     if (job != VIR_JOB_ASYNC &&
         job != VIR_JOB_DESTROY &&
-        cfg->maxQueuedJobs &&
-        priv->job.jobsQueued > cfg->maxQueuedJobs) {
+        priv->job.maxQueuedJobs &&
+        priv->job.jobsQueued > priv->job.maxQueuedJobs) {
         goto error;
     }
 
-    while (!nested && !qemuDomainNestedJobAllowed(&priv->job, job)) {
+    while (!nested && !virDomainNestedJobAllowed(&priv->job, job)) {
         if (nowait)
             goto cleanup;
 
@@ -892,7 +774,7 @@ qemuDomainObjBeginJobInternal(virQEMUDriver *driver,
             goto error;
     }
 
-    while (!qemuDomainObjCanSetJob(&priv->job, job, agentJob)) {
+    while (!virDomainObjCanSetJob(&priv->job, job, agentJob)) {
         if (nowait)
             goto cleanup;
 
@@ -903,7 +785,7 @@ qemuDomainObjBeginJobInternal(virQEMUDriver *driver,
 
     /* No job is active but a new async job could have been started while obj
      * was unlocked, so we need to recheck it. */
-    if (!nested && !qemuDomainNestedJobAllowed(&priv->job, job))
+    if (!nested && !virDomainNestedJobAllowed(&priv->job, job))
         goto retry;
 
     if (obj->removing) {
@@ -919,7 +801,7 @@ qemuDomainObjBeginJobInternal(virQEMUDriver *driver,
     ignore_value(virTimeMillisNow(&now));
 
     if (job) {
-        qemuDomainObjResetJob(&priv->job);
+        virDomainObjResetJob(&priv->job);
 
         if (job != VIR_JOB_ASYNC) {
             VIR_DEBUG("Started job: %s (async=%s vm=%p name=%s)",
@@ -934,8 +816,8 @@ qemuDomainObjBeginJobInternal(virQEMUDriver *driver,
             VIR_DEBUG("Started async job: %s (vm=%p name=%s)",
                       virDomainAsyncJobTypeToString(asyncJob),
                       obj, obj->def->name);
-            qemuDomainObjResetAsyncJob(&priv->job);
-            priv->job.current = virDomainJobDataInit(&qemuJobDataPrivateDataCallbacks);
+            virDomainObjResetAsyncJob(&priv->job);
+            priv->job.current = virDomainJobDataInit(priv->job.jobDataPrivateCb);
             priv->job.current->status = VIR_DOMAIN_JOB_STATUS_ACTIVE;
             priv->job.asyncJob = asyncJob;
             priv->job.asyncOwner = virThreadSelfID();
@@ -946,7 +828,7 @@ qemuDomainObjBeginJobInternal(virQEMUDriver *driver,
     }
 
     if (agentJob) {
-        qemuDomainObjResetAgentJob(&priv->job);
+        virDomainObjResetAgentJob(&priv->job);
 
         VIR_DEBUG("Started agent job: %s (vm=%p name=%s job=%s async=%s)",
                   virDomainAgentJobTypeToString(agentJob),
@@ -959,8 +841,8 @@ qemuDomainObjBeginJobInternal(virQEMUDriver *driver,
         priv->job.agentStarted = now;
     }
 
-    if (qemuDomainTrackJob(job))
-        qemuDomainSaveStatus(obj);
+    if (virDomainTrackJob(job) && priv->job.cb)
+        priv->job.cb->saveStatusPrivate(obj);
 
     return 0;
 
@@ -992,7 +874,7 @@ qemuDomainObjBeginJobInternal(virQEMUDriver *driver,
              duration / 1000, agentDuration / 1000, asyncDuration / 1000);
 
     if (job) {
-        if (nested || qemuDomainNestedJobAllowed(&priv->job, job))
+        if (nested || virDomainNestedJobAllowed(&priv->job, job))
             blocker = priv->job.ownerAPI;
         else
             blocker = priv->job.asyncOwnerAPI;
@@ -1022,8 +904,8 @@ qemuDomainObjBeginJobInternal(virQEMUDriver *driver,
                            _("cannot acquire state change lock"));
         }
         ret = -2;
-    } else if (cfg->maxQueuedJobs &&
-               priv->job.jobsQueued > cfg->maxQueuedJobs) {
+    } else if (priv->job.maxQueuedJobs &&
+               priv->job.jobsQueued > priv->job.maxQueuedJobs) {
         if (blocker && agentBlocker) {
             virReportError(VIR_ERR_OPERATION_FAILED,
                            _("cannot acquire state change "
@@ -1065,11 +947,10 @@ qemuDomainObjBeginJobInternal(virQEMUDriver *driver,
  *
  * Successful calls must be followed by EndJob eventually
  */
-int qemuDomainObjBeginJob(virQEMUDriver *driver,
-                          virDomainObj *obj,
+int qemuDomainObjBeginJob(virDomainObj *obj,
                           virDomainJob job)
 {
-    if (qemuDomainObjBeginJobInternal(driver, obj, job,
+    if (qemuDomainObjBeginJobInternal(obj, job,
                                       VIR_AGENT_JOB_NONE,
                                       VIR_ASYNC_JOB_NONE, false) < 0)
         return -1;
@@ -1084,24 +965,22 @@ int qemuDomainObjBeginJob(virQEMUDriver *driver,
  * To end job call qemuDomainObjEndAgentJob.
  */
 int
-qemuDomainObjBeginAgentJob(virQEMUDriver *driver,
-                           virDomainObj *obj,
+qemuDomainObjBeginAgentJob(virDomainObj *obj,
                            virDomainAgentJob agentJob)
 {
-    return qemuDomainObjBeginJobInternal(driver, obj, VIR_JOB_NONE,
+    return qemuDomainObjBeginJobInternal(obj, VIR_JOB_NONE,
                                          agentJob,
                                          VIR_ASYNC_JOB_NONE, false);
 }
 
-int qemuDomainObjBeginAsyncJob(virQEMUDriver *driver,
-                               virDomainObj *obj,
+int qemuDomainObjBeginAsyncJob(virDomainObj *obj,
                                virDomainAsyncJob asyncJob,
                                virDomainJobOperation operation,
                                unsigned long apiFlags)
 {
     qemuDomainObjPrivate *priv;
 
-    if (qemuDomainObjBeginJobInternal(driver, obj, VIR_JOB_ASYNC,
+    if (qemuDomainObjBeginJobInternal(obj, VIR_JOB_ASYNC,
                                       VIR_AGENT_JOB_NONE,
                                       asyncJob, false) < 0)
         return -1;
@@ -1113,8 +992,7 @@ int qemuDomainObjBeginAsyncJob(virQEMUDriver *driver,
 }
 
 int
-qemuDomainObjBeginNestedJob(virQEMUDriver *driver,
-                            virDomainObj *obj,
+qemuDomainObjBeginNestedJob(virDomainObj *obj,
                             virDomainAsyncJob asyncJob)
 {
     qemuDomainObjPrivate *priv = obj->privateData;
@@ -1131,7 +1009,7 @@ qemuDomainObjBeginNestedJob(virQEMUDriver *driver,
                  priv->job.asyncOwner);
     }
 
-    return qemuDomainObjBeginJobInternal(driver, obj,
+    return qemuDomainObjBeginJobInternal(obj,
                                          VIR_JOB_ASYNC_NESTED,
                                          VIR_AGENT_JOB_NONE,
                                          VIR_ASYNC_JOB_NONE,
@@ -1141,7 +1019,6 @@ qemuDomainObjBeginNestedJob(virQEMUDriver *driver,
 /**
  * qemuDomainObjBeginJobNowait:
  *
- * @driver: qemu driver
  * @obj: domain object
  * @job: virDomainJob to start
  *
@@ -1152,11 +1029,10 @@ qemuDomainObjBeginNestedJob(virQEMUDriver *driver,
  * Returns: see qemuDomainObjBeginJobInternal
  */
 int
-qemuDomainObjBeginJobNowait(virQEMUDriver *driver,
-                            virDomainObj *obj,
+qemuDomainObjBeginJobNowait(virDomainObj *obj,
                             virDomainJob job)
 {
-    return qemuDomainObjBeginJobInternal(driver, obj, job,
+    return qemuDomainObjBeginJobInternal(obj, job,
                                          VIR_AGENT_JOB_NONE,
                                          VIR_ASYNC_JOB_NONE, true);
 }
@@ -1180,8 +1056,8 @@ qemuDomainObjEndJob(virDomainObj *obj)
               virDomainAsyncJobTypeToString(priv->job.asyncJob),
               obj, obj->def->name);
 
-    qemuDomainObjResetJob(&priv->job);
-    if (qemuDomainTrackJob(job))
+    virDomainObjResetJob(&priv->job);
+    if (virDomainTrackJob(job))
         qemuDomainSaveStatus(obj);
     /* We indeed need to wake up ALL threads waiting because
      * grabbing a job requires checking more variables. */
@@ -1201,7 +1077,7 @@ qemuDomainObjEndAgentJob(virDomainObj *obj)
               virDomainAsyncJobTypeToString(priv->job.asyncJob),
               obj, obj->def->name);
 
-    qemuDomainObjResetAgentJob(&priv->job);
+    virDomainObjResetAgentJob(&priv->job);
     /* We indeed need to wake up ALL threads waiting because
      * grabbing a job requires checking more variables. */
     virCondBroadcast(&priv->job.cond);
@@ -1218,7 +1094,7 @@ qemuDomainObjEndAsyncJob(virDomainObj *obj)
               virDomainAsyncJobTypeToString(priv->job.asyncJob),
               obj, obj->def->name);
 
-    qemuDomainObjResetAsyncJob(&priv->job);
+    virDomainObjResetAsyncJob(&priv->job);
     qemuDomainSaveStatus(obj);
     virCondBroadcast(&priv->job.asyncCond);
 }
@@ -1245,7 +1121,7 @@ qemuDomainObjPrivateXMLFormatJob(virBuffer *buf,
     g_auto(virBuffer) childBuf = VIR_BUFFER_INIT_CHILD(buf);
     virDomainJob job = priv->job.active;
 
-    if (!qemuDomainTrackJob(job))
+    if (!virDomainTrackJob(job))
         job = VIR_JOB_NONE;
 
     if (job == VIR_JOB_NONE &&
