@@ -20,7 +20,6 @@
 
 #include <config.h>
 
-#include "qemu_command.h"
 #include "qemu_extdevice.h"
 #include "qemu_vhost_user_gpu.h"
 #include "qemu_dbus.h"
@@ -29,12 +28,8 @@
 #include "qemu_slirp.h"
 #include "qemu_virtiofs.h"
 
-#include "viralloc.h"
 #include "virlog.h"
-#include "virstring.h"
 #include "virtime.h"
-#include "virtpm.h"
-#include "virpidfile.h"
 
 #define VIR_FROM_THIS VIR_FROM_QEMU
 
@@ -73,8 +68,15 @@ static int
 qemuExtDevicesInitPaths(virQEMUDriver *driver,
                         virDomainDef *def)
 {
-    if (def->ntpms > 0)
-        return qemuExtTPMInitPaths(driver, def);
+    size_t i;
+
+    for (i = 0; i < def->ntpms; i++) {
+        virDomainTPMDef *tpm = def->tpms[i];
+
+        if (tpm->type == VIR_DOMAIN_TPM_TYPE_EMULATOR &&
+            qemuExtTPMInitPaths(driver, def, tpm) < 0)
+            return -1;
+    }
 
     return 0;
 }
@@ -135,15 +137,11 @@ qemuExtDevicesPrepareHost(virQEMUDriver *driver,
     if (qemuExtDevicesInitPaths(driver, def) < 0)
         return -1;
 
-    if (def->ntpms > 0 &&
-        qemuExtTPMPrepareHost(driver, def) < 0)
-        return -1;
+    for (i = 0; i < def->ntpms; i++) {
+        virDomainTPMDef *tpm = def->tpms[i];
 
-    for (i = 0; i < def->nnets; i++) {
-        virDomainNetDef *net = def->nets[i];
-        qemuSlirp *slirp = QEMU_DOMAIN_NETWORK_PRIVATE(net)->slirp;
-
-        if (slirp && qemuSlirpOpen(slirp, driver, def) < 0)
+        if (tpm->type == VIR_DOMAIN_TPM_TYPE_EMULATOR &&
+            qemuExtTPMPrepareHost(driver, def, tpm) < 0)
             return -1;
     }
 
@@ -155,11 +153,14 @@ void
 qemuExtDevicesCleanupHost(virQEMUDriver *driver,
                           virDomainDef *def)
 {
+    size_t i;
+
     if (qemuExtDevicesInitPaths(driver, def) < 0)
         return;
 
-    if (def->ntpms > 0)
-        qemuExtTPMCleanupHost(def);
+    for (i = 0; i < def->ntpms; i++) {
+        qemuExtTPMCleanupHost(def->tpms[i]);
+    }
 }
 
 
@@ -180,15 +181,18 @@ qemuExtDevicesStart(virQEMUDriver *driver,
         }
     }
 
-    if (def->ntpms > 0 && qemuExtTPMStart(driver, vm, incomingMigration) < 0)
-        return -1;
+    for (i = 0; i < def->ntpms; i++) {
+        virDomainTPMDef *tpm = def->tpms[i];
+
+        if (tpm->type == VIR_DOMAIN_TPM_TYPE_EMULATOR &&
+            qemuExtTPMStart(driver, vm, tpm, incomingMigration) < 0)
+            return -1;
+    }
 
     for (i = 0; i < def->nnets; i++) {
         virDomainNetDef *net = def->nets[i];
-        qemuSlirp *slirp = QEMU_DOMAIN_NETWORK_PRIVATE(net)->slirp;
 
-        if (slirp &&
-            qemuSlirpStart(slirp, vm, driver, net, incomingMigration) < 0)
+        if (qemuSlirpStart(vm, net, incomingMigration) < 0)
             return -1;
     }
 
@@ -201,6 +205,19 @@ qemuExtDevicesStart(virQEMUDriver *driver,
         }
     }
 
+    for (i = 0; i < def->ngraphics; i++) {
+        virDomainGraphicsDef *graphics = def->graphics[i];
+
+        if (graphics->type != VIR_DOMAIN_GRAPHICS_TYPE_DBUS)
+            continue;
+
+        if (graphics->data.dbus.p2p || graphics->data.dbus.fromConfig)
+            continue;
+
+        if (qemuDBusStart(driver, vm) < 0)
+            return -1;
+    }
+
     return 0;
 }
 
@@ -222,8 +239,10 @@ qemuExtDevicesStop(virQEMUDriver *driver,
             qemuExtVhostUserGPUStop(driver, vm, video);
     }
 
-    if (def->ntpms > 0)
-        qemuExtTPMStop(driver, vm);
+    for (i = 0; i < def->ntpms; i++) {
+        if (def->tpms[i]->type == VIR_DOMAIN_TPM_TYPE_EMULATOR)
+            qemuExtTPMStop(driver, vm);
+    }
 
     for (i = 0; i < def->nnets; i++) {
         virDomainNetDef *net = def->nets[i];
@@ -299,9 +318,11 @@ qemuExtDevicesSetupCgroup(virQEMUDriver *driver,
             return -1;
     }
 
-    if (def->ntpms > 0 &&
-        qemuExtTPMSetupCgroup(driver, def, cgroup) < 0)
-        return -1;
+    for (i = 0; i < def->ntpms; i++) {
+        if (def->tpms[i]->type == VIR_DOMAIN_TPM_TYPE_EMULATOR &&
+            qemuExtTPMSetupCgroup(driver, def, cgroup) < 0)
+            return -1;
+    }
 
     for (i = 0; i < def->nfss; i++) {
         virDomainFSDef *fs = def->fss[i];
