@@ -222,12 +222,6 @@ typedef void (*qemuMonitorDomainGraphicsCallback)(qemuMonitor *mon,
                                                   const char *authScheme,
                                                   const char *x509dname,
                                                   const char *saslUsername);
-typedef void (*qemuMonitorDomainBlockJobCallback)(qemuMonitor *mon,
-                                                  virDomainObj *vm,
-                                                  const char *diskAlias,
-                                                  int type,
-                                                  int status,
-                                                  const char *error);
 typedef void (*qemuMonitorDomainJobStatusChangeCallback)(qemuMonitor *mon,
                                                          virDomainObj *vm,
                                                          const char *jobname,
@@ -381,7 +375,6 @@ struct _qemuMonitorCallbacks {
     qemuMonitorDomainWatchdogCallback domainWatchdog;
     qemuMonitorDomainIOErrorCallback domainIOError;
     qemuMonitorDomainGraphicsCallback domainGraphics;
-    qemuMonitorDomainBlockJobCallback domainBlockJob;
     qemuMonitorDomainJobStatusChangeCallback jobStatusChange;
     qemuMonitorDomainTrayChangeCallback domainTrayChange;
     qemuMonitorDomainPMWakeupCallback domainPMWakeup;
@@ -408,11 +401,9 @@ struct _qemuMonitorCallbacks {
 
 qemuMonitor *qemuMonitorOpen(virDomainObj *vm,
                                virDomainChrSourceDef *config,
-                               bool retry,
-                               unsigned long long timeout,
                                GMainContext *context,
                                qemuMonitorCallbacks *cb)
-    ATTRIBUTE_NONNULL(1) ATTRIBUTE_NONNULL(2) ATTRIBUTE_NONNULL(5);
+    ATTRIBUTE_NONNULL(1) ATTRIBUTE_NONNULL(2) ATTRIBUTE_NONNULL(4);
 
 void qemuMonitorWatchDispose(void);
 bool qemuMonitorWasDisposed(void);
@@ -476,11 +467,6 @@ void qemuMonitorEmitTrayChange(qemuMonitor *mon,
                                int reason);
 void qemuMonitorEmitPMWakeup(qemuMonitor *mon);
 void qemuMonitorEmitPMSuspend(qemuMonitor *mon);
-void qemuMonitorEmitBlockJob(qemuMonitor *mon,
-                             const char *diskAlias,
-                             int type,
-                             int status,
-                             const char *error);
 void qemuMonitorEmitJobStatusChange(qemuMonitor *mon,
                                     const char *jobname,
                                     qemuMonitorJobStatus status);
@@ -646,11 +632,9 @@ void qemuMonitorCPUInfoFree(qemuMonitorCPUInfo *list,
 int qemuMonitorGetCPUInfo(qemuMonitor *mon,
                           qemuMonitorCPUInfo **vcpus,
                           size_t maxvcpus,
-                          bool hotplug,
-                          bool fast);
+                          bool hotplug);
 virBitmap *qemuMonitorGetCpuHalted(qemuMonitor *mon,
-                                     size_t maxvcpus,
-                                     bool fast);
+                                   size_t maxvcpus);
 
 int qemuMonitorGetBalloonInfo(qemuMonitor *mon,
                               unsigned long long *currmem);
@@ -693,10 +677,6 @@ int qemuMonitorGetAllBlockStatsInfo(qemuMonitor *mon,
                                     GHashTable **ret_stats)
     ATTRIBUTE_NONNULL(2);
 
-int qemuMonitorBlockStatsUpdateCapacity(qemuMonitor *mon,
-                                        GHashTable *stats)
-    ATTRIBUTE_NONNULL(2);
-
 int qemuMonitorBlockStatsUpdateCapacityBlockdev(qemuMonitor *mon,
                                                 GHashTable *stats)
     ATTRIBUTE_NONNULL(2);
@@ -749,15 +729,6 @@ int qemuMonitorExpirePassword(qemuMonitor *mon,
 int qemuMonitorSetBalloon(qemuMonitor *mon,
                           unsigned long long newmem);
 
-int qemuMonitorEjectMedia(qemuMonitor *mon,
-                          const char *dev_name,
-                          bool force);
-int qemuMonitorChangeMedia(qemuMonitor *mon,
-                           const char *dev_name,
-                           const char *newmedia,
-                           const char *format);
-
-
 int qemuMonitorSaveVirtualMemory(qemuMonitor *mon,
                                  unsigned long long offset,
                                  unsigned long long length,
@@ -980,27 +951,11 @@ int qemuMonitorDelObject(qemuMonitor *mon,
                          const char *objalias,
                          bool report_error);
 
-int qemuMonitorAddDrive(qemuMonitor *mon,
-                        const char *drivestr);
-
-int qemuMonitorDriveDel(qemuMonitor *mon,
-                        const char *drivestr);
-
 int qemuMonitorCreateSnapshot(qemuMonitor *mon, const char *name);
 int qemuMonitorDeleteSnapshot(qemuMonitor *mon, const char *name);
 
 int qemuMonitorTransaction(qemuMonitor *mon, virJSONValue **actions)
     ATTRIBUTE_NONNULL(2);
-int qemuMonitorDriveMirror(qemuMonitor *mon,
-                           const char *device,
-                           const char *file,
-                           const char *format,
-                           unsigned long long bandwidth,
-                           unsigned int granularity,
-                           unsigned long long buf_size,
-                           bool shallow,
-                           bool reuse)
-    ATTRIBUTE_NONNULL(2) ATTRIBUTE_NONNULL(3);
 int qemuMonitorBlockdevMirror(qemuMonitor *mon,
                               const char *jobname,
                               bool persistjob,
@@ -1012,26 +967,15 @@ int qemuMonitorBlockdevMirror(qemuMonitor *mon,
                               bool shallow,
                               bool syncWrite)
     ATTRIBUTE_NONNULL(4) ATTRIBUTE_NONNULL(5);
-int qemuMonitorDrivePivot(qemuMonitor *mon,
-                          const char *jobname)
-    ATTRIBUTE_NONNULL(2);
 
 int qemuMonitorBlockCommit(qemuMonitor *mon,
                            const char *device,
                            const char *jobname,
-                           bool persistjob,
-                           const char *top,
                            const char *topNode,
-                           const char *base,
                            const char *baseNode,
                            const char *backingName,
                            unsigned long long bandwidth)
     ATTRIBUTE_NONNULL(2);
-char *qemuMonitorDiskNameLookup(qemuMonitor *mon,
-                                const char *device,
-                                virStorageSource *top,
-                                virStorageSource *target)
-    ATTRIBUTE_NONNULL(2) ATTRIBUTE_NONNULL(3) ATTRIBUTE_NONNULL(4);
 
 int qemuMonitorArbitraryCommand(qemuMonitor *mon,
                                 const char *cmd,
@@ -1054,8 +998,6 @@ int qemuMonitorSendKey(qemuMonitor *mon,
 int qemuMonitorBlockStream(qemuMonitor *mon,
                            const char *device,
                            const char *jobname,
-                           bool persistjob,
-                           const char *base,
                            const char *baseNode,
                            const char *backingName,
                            unsigned long long bandwidth)
@@ -1347,8 +1289,6 @@ int qemuMonitorSetBlockThreshold(qemuMonitor *mon,
                                  const char *nodename,
                                  unsigned long long threshold);
 
-virJSONValue *qemuMonitorQueryNamedBlockNodes(qemuMonitor *mon);
-
 int qemuMonitorSetWatchdogAction(qemuMonitor *mon,
                                  const char *action);
 
@@ -1461,12 +1401,6 @@ qemuMonitorTransactionBitmapMergeSourceAddBitmap(virJSONValue *sources,
                                                  const char *sourcebitmap);
 
 int
-qemuMonitorTransactionSnapshotLegacy(virJSONValue *actions,
-                                     const char *device,
-                                     const char *path,
-                                     const char *format,
-                                     bool existing);
-int
 qemuMonitorTransactionSnapshotBlockdev(virJSONValue *actions,
                                        const char *node,
                                        const char *overlay);
@@ -1547,3 +1481,51 @@ qemuMonitorMigrateRecover(qemuMonitor *mon,
 int
 qemuMonitorGetMigrationBlockers(qemuMonitor *mon,
                                 char ***blockers);
+
+typedef enum {
+    QEMU_MONITOR_QUERY_STATS_TARGET_VM,
+    QEMU_MONITOR_QUERY_STATS_TARGET_VCPU,
+    QEMU_MONITOR_QUERY_STATS_TARGET_LAST,
+} qemuMonitorQueryStatsTargetType;
+
+VIR_ENUM_DECL(qemuMonitorQueryStatsTarget);
+
+typedef enum {
+    QEMU_MONITOR_QUERY_STATS_NAME_HALT_POLL_SUCCESS_NS,
+    QEMU_MONITOR_QUERY_STATS_NAME_HALT_POLL_FAIL_NS,
+    QEMU_MONITOR_QUERY_STATS_NAME_LAST,
+} qemuMonitorQueryStatsNameType;
+
+VIR_ENUM_DECL(qemuMonitorQueryStatsName);
+
+typedef enum {
+    QEMU_MONITOR_QUERY_STATS_PROVIDER_KVM,
+    QEMU_MONITOR_QUERY_STATS_PROVIDER_LAST,
+} qemuMonitorQueryStatsProviderType;
+
+VIR_ENUM_DECL(qemuMonitorQueryStatsProvider);
+
+typedef struct _qemuMonitorQueryStatsProvider qemuMonitorQueryStatsProvider;
+struct _qemuMonitorQueryStatsProvider {
+    qemuMonitorQueryStatsProviderType type;
+    virBitmap *names;
+};
+
+void
+qemuMonitorQueryStatsProviderFree(qemuMonitorQueryStatsProvider *provider);
+
+qemuMonitorQueryStatsProvider *
+qemuMonitorQueryStatsProviderNew(qemuMonitorQueryStatsProviderType provider_type,
+                                 ...);
+
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(qemuMonitorQueryStatsProvider,
+                              qemuMonitorQueryStatsProviderFree);
+
+virJSONValue *
+qemuMonitorQueryStats(qemuMonitor *mon,
+                      qemuMonitorQueryStatsTargetType target,
+                      char **vcpus,
+                      GPtrArray *providers);
+
+GHashTable *
+qemuMonitorExtractQueryStats(virJSONValue *info);
