@@ -349,7 +349,7 @@ mymain(void)
     DO_TEST_NOCAPS("disk-network-tlsx509-nbd");
     DO_TEST_CAPS_LATEST("disk-network-tlsx509-nbd-hostname");
     DO_TEST_NOCAPS("disk-network-tlsx509-vxhs");
-    DO_TEST("disk-nvme", QEMU_CAPS_VIRTIO_SCSI, QEMU_CAPS_QCOW2_LUKS);
+    DO_TEST_CAPS_LATEST("disk-nvme");
     DO_TEST_CAPS_LATEST("disk-vhostuser");
     DO_TEST_CAPS_LATEST("disk-scsi");
     DO_TEST("disk-virtio-scsi-reservations",
@@ -411,8 +411,7 @@ mymain(void)
             QEMU_CAPS_DISPLAY_DBUS);
     DO_TEST("graphics-dbus-audio",
             QEMU_CAPS_DEVICE_CIRRUS_VGA,
-            QEMU_CAPS_DISPLAY_DBUS,
-            QEMU_CAPS_AUDIODEV);
+            QEMU_CAPS_DISPLAY_DBUS);
     DO_TEST("graphics-dbus-chardev",
             QEMU_CAPS_DEVICE_CIRRUS_VGA,
             QEMU_CAPS_DISPLAY_DBUS);
@@ -465,7 +464,7 @@ mymain(void)
     DO_TEST_NOCAPS("net-user");
     DO_TEST_NOCAPS("net-user-addr");
     DO_TEST_NOCAPS("net-virtio");
-    DO_TEST("net-virtio-device", QEMU_CAPS_VIRTIO_TX_ALG);
+    DO_TEST_NOCAPS("net-virtio-device");
     DO_TEST_NOCAPS("net-virtio-disable-offloads");
     DO_TEST_NOCAPS("net-eth");
     DO_TEST_NOCAPS("net-eth-ifname");
@@ -571,8 +570,8 @@ mymain(void)
     DO_TEST_CAPS_LATEST("disk-slices");
     DO_TEST_CAPS_LATEST("disk-rotation");
 
-    DO_TEST("encrypted-disk", QEMU_CAPS_QCOW2_LUKS);
-    DO_TEST("encrypted-disk-usage", QEMU_CAPS_QCOW2_LUKS);
+    DO_TEST_CAPS_LATEST("encrypted-disk");
+    DO_TEST_CAPS_LATEST("encrypted-disk-usage");
     DO_TEST_CAPS_LATEST("luks-disks");
     DO_TEST_CAPS_LATEST("luks-disks-source");
     DO_TEST_CAPS_LATEST("luks-disks-source-qcow2");
@@ -748,7 +747,7 @@ mymain(void)
     DO_TEST_NOCAPS("numad-auto-memory-vcpu-no-cpuset-and-placement");
     DO_TEST_NOCAPS("numad-auto-memory-vcpu-cpuset");
     DO_TEST_NOCAPS("usb-ich9-ehci-addr");
-    DO_TEST("disk-copy_on_read", QEMU_CAPS_VIRTIO_TX_ALG);
+    DO_TEST_NOCAPS("disk-copy_on_read");
     DO_TEST_CAPS_LATEST("tpm-passthrough");
     DO_TEST_CAPS_LATEST("tpm-passthrough-crb");
     DO_TEST_CAPS_LATEST("tpm-emulator");
@@ -1028,14 +1027,12 @@ mymain(void)
     DO_TEST("s390-serial-2", QEMU_CAPS_CCW);
     DO_TEST("s390-serial-console", QEMU_CAPS_CCW);
 
-    DO_TEST("pcihole64", QEMU_CAPS_I440FX_PCI_HOLE64_SIZE);
-    DO_TEST("pcihole64-gib", QEMU_CAPS_I440FX_PCI_HOLE64_SIZE);
-    DO_TEST("pcihole64-none", QEMU_CAPS_I440FX_PCI_HOLE64_SIZE);
+    DO_TEST_NOCAPS("pcihole64");
+    DO_TEST_NOCAPS("pcihole64-gib");
     DO_TEST("pcihole64-q35",
             QEMU_CAPS_DEVICE_IOH3420,
             QEMU_CAPS_ICH9_AHCI,
-            QEMU_CAPS_DEVICE_QXL,
-            QEMU_CAPS_Q35_PCI_HOLE64_SIZE);
+            QEMU_CAPS_DEVICE_QXL);
 
     DO_TEST("panic", QEMU_CAPS_DEVICE_PANIC);
     DO_TEST("panic-double", QEMU_CAPS_DEVICE_PANIC);
@@ -1175,6 +1172,7 @@ mymain(void)
                  QEMU_CAPS_OBJECT_MEMORY_FILE, QEMU_CAPS_LAST, ARG_END);
     DO_TEST_NOCAPS("memory-hotplug");
     DO_TEST("memory-hotplug-dimm", QEMU_CAPS_DEVICE_PC_DIMM);
+    DO_TEST_CAPS_LATEST("memory-hotplug-dimm-addr");
     DO_TEST("memory-hotplug-nvdimm", QEMU_CAPS_DEVICE_NVDIMM);
     DO_TEST("memory-hotplug-nvdimm-access", QEMU_CAPS_DEVICE_NVDIMM);
     DO_TEST("memory-hotplug-nvdimm-label", QEMU_CAPS_DEVICE_NVDIMM);
@@ -1297,14 +1295,7 @@ mymain(void)
     DO_TEST_CAPS_ARCH_LATEST("pseries-cpu-compat", "ppc64");
     DO_TEST_CAPS_ARCH_LATEST("pseries-cpu-exact", "ppc64");
 
-    DO_TEST("user-aliases",
-            QEMU_CAPS_DEVICE_CIRRUS_VGA,
-            QEMU_CAPS_QCOW2_LUKS,
-            QEMU_CAPS_OBJECT_MEMORY_FILE,
-            QEMU_CAPS_PIIX_DISABLE_S3,
-            QEMU_CAPS_PIIX_DISABLE_S4,
-            QEMU_CAPS_VNC,
-            QEMU_CAPS_CCID_EMULATED);
+    DO_TEST_CAPS_LATEST("user-aliases");
     DO_TEST("input-virtio-ccw",
             QEMU_CAPS_CCW,
             QEMU_CAPS_VIRTIO_KEYBOARD,
@@ -1334,7 +1325,6 @@ mymain(void)
     DO_TEST("riscv64-virt-pci",
             QEMU_CAPS_OBJECT_GPEX);
 
-    DO_TEST_CAPS_VER("x86-kvm-32-on-64", "4.1.0");
     DO_TEST_CAPS_LATEST("x86-kvm-32-on-64");
 
     DO_TEST_CAPS_LATEST("virtio-transitional");
@@ -1405,18 +1395,17 @@ mymain(void)
     DO_TEST_NOCAPS("audio-file-best");
 
     /* Full <audio> only compat with new QEMU -audiodev args */
-    DO_TEST("audio-none-full", QEMU_CAPS_AUDIODEV);
-    DO_TEST("audio-alsa-full", QEMU_CAPS_AUDIODEV);
-    DO_TEST("audio-coreaudio-full", QEMU_CAPS_AUDIODEV);
-    DO_TEST("audio-jack-full", QEMU_CAPS_AUDIODEV);
-    DO_TEST("audio-oss-full", QEMU_CAPS_AUDIODEV);
-    DO_TEST("audio-pulseaudio-full", QEMU_CAPS_AUDIODEV);
-    DO_TEST("audio-sdl-full", QEMU_CAPS_AUDIODEV);
+    DO_TEST_NOCAPS("audio-none-full");
+    DO_TEST_NOCAPS("audio-alsa-full");
+    DO_TEST_NOCAPS("audio-coreaudio-full");
+    DO_TEST_NOCAPS("audio-jack-full");
+    DO_TEST_NOCAPS("audio-oss-full");
+    DO_TEST_NOCAPS("audio-pulseaudio-full");
+    DO_TEST_NOCAPS("audio-sdl-full");
     DO_TEST("audio-spice-full",
-            QEMU_CAPS_AUDIODEV,
             QEMU_CAPS_SPICE,
             QEMU_CAPS_DEVICE_CIRRUS_VGA);
-    DO_TEST("audio-file-full", QEMU_CAPS_AUDIODEV);
+    DO_TEST_NOCAPS("audio-file-full");
 
     DO_TEST_CAPS_LATEST("audio-many-backends");
 
