@@ -25,7 +25,6 @@
 
 # define LIBVIRT_VIRCGROUPPRIV_H_ALLOW
 # include "vircgrouppriv.h"
-# include "virstring.h"
 # include "virerror.h"
 # include "virlog.h"
 # include "virfile.h"
@@ -174,7 +173,7 @@ testCgroupDetectMounts(const void *args)
 {
     int result = -1;
     const struct _detectMountsData *data = args;
-    char *parsed = NULL;
+    g_autofree char *parsed = NULL;
     const char *actual;
     g_autoptr(virCgroup) group = NULL;
     g_auto(virBuffer) buf = VIR_BUFFER_INITIALIZER;
@@ -209,7 +208,6 @@ testCgroupDetectMounts(const void *args)
 
  cleanup:
     g_unsetenv("VIR_CGROUP_MOCK_FILENAME");
-    VIR_FREE(parsed);
     return result;
 }
 
